@@ -6,7 +6,7 @@ use warnings;
 
 use Scalar::Util 'blessed';
 
-our $VERSION = '0.05';
+our $VERSION = '0.06';
 
 # this is our global stash of both 
 # MRO's and method dispatch tables
@@ -18,7 +18,8 @@ our $VERSION = '0.05';
 #      methods => {
 #          orig => <original location of method>,
 #          code => \&<ref to original method>
-#      }
+#      },
+#      has_overload_fallback => (1 | 0)
 #   }
 #
 my %MRO;
@@ -85,12 +86,18 @@ sub _calculate_method_dispatch_table {
     no strict 'refs';
     my @MRO = calculateMRO($class);
     $MRO{$class} = { MRO => \@MRO };
+    my $has_overload_fallback = 0;
     my %methods;
     # NOTE: 
     # we do @MRO[1 .. $#MRO] here because it
     # makes no sense to interogate the class
     # which you are calculating for. 
     foreach my $local (@MRO[1 .. $#MRO]) {
+        # if overload has tagged this module to 
+        # have use "fallback", then we want to
+        # grab that value 
+        $has_overload_fallback = ${"${local}::()"} 
+            if defined ${"${local}::()"};
         foreach my $method (grep { defined &{"${local}::$_"} } keys %{"${local}::"}) {
             # skip if already overriden in local class
             next unless !defined *{"${class}::$method"}{CODE};
@@ -101,7 +108,8 @@ sub _calculate_method_dispatch_table {
         }
     }    
     # now stash them in our %MRO table
-    $MRO{$class}->{methods} = \%methods;    
+    $MRO{$class}->{methods} = \%methods; 
+    $MRO{$class}->{has_overload_fallback} = $has_overload_fallback;        
 }
 
 sub _apply_method_dispatch_tables {
@@ -113,6 +121,8 @@ sub _apply_method_dispatch_tables {
 sub _apply_method_dispatch_table {
     my $class = shift;
     no strict 'refs';
+    ${"${class}::()"} = $MRO{$class}->{has_overload_fallback}
+        if $MRO{$class}->{has_overload_fallback};
     foreach my $method (keys %{$MRO{$class}->{methods}}) {
         *{"${class}::$method"} = $MRO{$class}->{methods}->{$method}->{code};
     }    
@@ -127,6 +137,7 @@ sub _remove_method_dispatch_tables {
 sub _remove_method_dispatch_table {
     my $class = shift;
     no strict 'refs';
+    delete ${"${class}::"}{"()"} if $MRO{$class}->{has_overload_fallback};    
     foreach my $method (keys %{$MRO{$class}->{methods}}) {
         delete ${"${class}::"}{$method};
     }   
@@ -139,12 +150,14 @@ sub _remove_method_dispatch_table {
 #   http://www.python.org/2.3/mro.html
 sub _merge {                
     my (@seqs) = @_;
+    my $class_being_merged = $seqs[0]->[0];
     my @res; 
     while (1) {
         # remove all empty seqences
         my @nonemptyseqs = (map { (@{$_} ? $_ : ()) } @seqs);
         # return the list if we have no more no-empty sequences
         return @res if not @nonemptyseqs; 
+        my $reject;
         my $cand; # a canidate ..
         foreach my $seq (@nonemptyseqs) {
             $cand = $seq->[0]; # get the head of the list
@@ -159,9 +172,12 @@ sub _merge {
                 $nothead++ && last if exists $in_tail{$cand};      
             }
             last unless $nothead; # leave the loop with our canidate ...
+            $reject = $cand;
             $cand = undef;        # otherwise, reject it ...
         }
-        die "Inconsistent hierarchy" if not $cand;
+        die "Inconsistent hierarchy found while merging '$class_being_merged':\n\t" .
+            "current merge results [\n\t\t" . (join ",\n\t\t" => @res) . "\n\t]\n\t" .
+            "mergeing failed on '$reject'\n" if not $cand;
         push @res => $cand;
         # now loop through our non-empties and pop 
         # off the head if it matches our canidate
